@@ -1,5 +1,5 @@
 package GitLab::API::v4::Paginator;
-$GitLab::API::v4::Paginator::VERSION = '0.02';
+$GitLab::API::v4::Paginator::VERSION = '0.03';
 =head1 NAME
 
 GitLab::API::v4::Paginator - Iterate through paginated GitLab v4 API records.
@@ -17,7 +17,7 @@ use Types::Common::String -types;
 use Carp qw( croak );
 
 use Moo;
-use strictures 1;
+use strictures 2;
 use namespace::clean;
 
 =head1 REQUIRED ARGUMENTS
@@ -211,9 +211,9 @@ sub reset {
 1;
 __END__
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Aran Clary Deltac <bluefeetE<64>gmail.com>
+See L<GitLab::API::v4/AUTHOR> and L<GitLab::API::v4/CONTRIBUTORS>.
 
 =head1 LICENSE
 
